git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: Karthik Nayak <karthik.188@gmail.com>
To: git@vger.kernel.org
Cc: gitster@pobox.com, sunshine@sunshineco.com,
	Karthik Nayak <Karthik.188@gmail.com>
Subject: [PATCH v2 01/11] strbuf: introduce strbuf_split_str_without_term()
Date: Wed, 16 Dec 2015 20:59:52 +0530	[thread overview]
Message-ID: <1450279802-29414-2-git-send-email-Karthik.188@gmail.com> (raw)
In-Reply-To: <1450279802-29414-1-git-send-email-Karthik.188@gmail.com>

The current implementation of 'strbuf_split_buf()' includes the
terminator at the end of each strbuf post splitting. Add an option
wherein we can drop the terminator if desired. In this context
introduce a wrapper function 'strbuf_split_str_without_term()' which
splits a given string into strbufs without including the terminator.

Signed-off-by: Karthik Nayak <Karthik.188@gmail.com>
---
 strbuf.c |  7 ++++---
 strbuf.h | 25 ++++++++++++++++---------
 2 files changed, 20 insertions(+), 12 deletions(-)

diff --git a/strbuf.c b/strbuf.c
index b552a13..b62508e 100644
--- a/strbuf.c
+++ b/strbuf.c
@@ -115,7 +115,7 @@ void strbuf_tolower(struct strbuf *sb)
 }
 
 struct strbuf **strbuf_split_buf(const char *str, size_t slen,
-				 int terminator, int max)
+				 int terminator, int max, int omit_term)
 {
 	struct strbuf **ret = NULL;
 	size_t nr = 0, alloc = 0;
@@ -123,14 +123,15 @@ struct strbuf **strbuf_split_buf(const char *str, size_t slen,
 
 	while (slen) {
 		int len = slen;
+		const char *end = NULL;
 		if (max <= 0 || nr + 1 < max) {
-			const char *end = memchr(str, terminator, slen);
+			end = memchr(str, terminator, slen);
 			if (end)
 				len = end - str + 1;
 		}
 		t = xmalloc(sizeof(struct strbuf));
 		strbuf_init(t, len);
-		strbuf_add(t, str, len);
+		strbuf_add(t, str, len - !!end * !!omit_term);
 		ALLOC_GROW(ret, nr + 2, alloc);
 		ret[nr++] = t;
 		str += len;
diff --git a/strbuf.h b/strbuf.h
index 6ae7a72..a865a74 100644
--- a/strbuf.h
+++ b/strbuf.h
@@ -450,11 +450,12 @@ static inline int strbuf_strip_suffix(struct strbuf *sb, const char *suffix)
 /**
  * Split str (of length slen) at the specified terminator character.
  * Return a null-terminated array of pointers to strbuf objects
  * holding the substrings.  The substrings include the terminator,
  * except for the last substring, which might be unterminated if the
  * original string did not end with a terminator.  If max is positive,
  * then split the string into at most max substrings (with the last
  * substring containing everything following the (max-1)th terminator
  * character).
  *
  * The most generic form is `strbuf_split_buf`, which takes an arbitrary
@@ -465,19 +466,25 @@ static inline int strbuf_strip_suffix(struct strbuf *sb, const char *suffix)
  * For lighter-weight alternatives, see string_list_split() and
  * string_list_split_in_place().
  */
-extern struct strbuf **strbuf_split_buf(const char *, size_t,
-					int terminator, int max);
+extern struct strbuf **strbuf_split_buf(const char *str, size_t slen,
+					int terminator, int max, int omit_term);
+
+static inline struct strbuf **strbuf_split_str_omit_term(const char *str,
+							    int terminator, int max)
+{
+	return strbuf_split_buf(str, strlen(str), terminator, max, 1);
+}
 
 static inline struct strbuf **strbuf_split_str(const char *str,
 					       int terminator, int max)
 {
-	return strbuf_split_buf(str, strlen(str), terminator, max);
+	return strbuf_split_buf(str, strlen(str), terminator, max, 0);
 }
 
 static inline struct strbuf **strbuf_split_max(const struct strbuf *sb,
 						int terminator, int max)
 {
-	return strbuf_split_buf(sb->buf, sb->len, terminator, max);
+	return strbuf_split_buf(sb->buf, sb->len, terminator, max, 0);
 }
 
 static inline struct strbuf **strbuf_split(const struct strbuf *sb,
@@ -450,11 +450,12 @@ static inline int strbuf_strip_suffix(struct strbuf *sb, const char *suffix)
  * Split str (of length slen) at the specified terminator character.
  * Return a null-terminated array of pointers to strbuf objects
- * holding the substrings.  The substrings include the terminator,
- * except for the last substring, which might be unterminated if the
- * original string did not end with a terminator.  If max is positive,
- * then split the string into at most max substrings (with the last
- * substring containing everything following the (max-1)th terminator
+ * holding the substrings.  The substrings include the terminator if
+ * the value of omit_term is '0' else the terminator is excluded.  The
+ * last substring, might be unterminated if the original string did
+ * not end with a terminator.  If max is positive, then split the
+ * string into at most max substrings (with the last substring
+ * containing everything following the (max-1)th terminator
  * character).
  *
-- 
2.6.4

  reply	other threads:[~2015-12-16 15:29 UTC|newest]

Thread overview: 34+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-12-16 15:29 [PATCH v2 00/11] ref-filter: use parsing functions Karthik Nayak
2015-12-16 15:29 ` Karthik Nayak [this message]
2015-12-16 20:35   ` [PATCH v2 01/11] strbuf: introduce strbuf_split_str_without_term() Eric Sunshine
2015-12-17  8:24     ` Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 02/11] ref-filter: use strbuf_split_str_omit_term() Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 03/11] ref-filter: introduce struct used_atom Karthik Nayak
2015-12-16 20:57   ` Eric Sunshine
2015-12-19  4:42     ` Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 04/11] ref-fitler: bump match_atom() name to the top Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 05/11] ref-filter: skip deref specifier in match_atom_name() Karthik Nayak
2015-12-16 21:11   ` Eric Sunshine
2015-12-19  5:07     ` Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 06/11] ref-filter: introduce color_atom_parser() Karthik Nayak
2015-12-16 21:21   ` Eric Sunshine
2015-12-19  6:00     ` Karthik Nayak
2015-12-16 15:29 ` [PATCH v2 07/11] ref-filter: introduce align_atom_parser() Karthik Nayak
2015-12-16 21:54   ` Eric Sunshine
2015-12-19 11:12     ` Karthik Nayak
2015-12-19 11:35       ` Karthik Nayak
2015-12-18  5:50   ` Eric Sunshine
2015-12-16 15:29 ` [PATCH v2 08/11] ref-filter: introduce prefixes for the align atom Karthik Nayak
2015-12-17  8:59   ` Eric Sunshine
2015-12-31 13:19     ` Karthik Nayak
2015-12-16 15:30 ` [PATCH v2 09/11] ref-filter: introduce remote_ref_atom_parser() Karthik Nayak
2015-12-17  9:22   ` Eric Sunshine
2015-12-24  7:42     ` Karthik Nayak
2015-12-16 15:30 ` [PATCH v2 10/11] ref-filter: introduce contents_atom_parser() Karthik Nayak
2015-12-17  9:39   ` Eric Sunshine
2015-12-24  8:27     ` Karthik Nayak
2015-12-16 15:30 ` [PATCH v2 11/11] ref-filter: introduce objectname_atom_parser() Karthik Nayak
2015-12-18  6:24   ` Eric Sunshine
2015-12-25 13:44     ` Karthik Nayak
2015-12-25 18:09       ` Eric Sunshine
2015-12-25 18:24         ` Karthik Nayak

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1450279802-29414-2-git-send-email-Karthik.188@gmail.com \
    --to=karthik.188@gmail.com \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=sunshine@sunshineco.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).